/* m68hc05.h -- Motorola 68HC05 opcodelist
   Copyright 2004 Martin Kgler
   Contributed by Martin Kgler (mkoegler@auto.tuwien.ac.at)

   This file is part of GAS, the GNU Assembler, and GDB, the GNU Debugger.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA 02110-1301, USA.  */

/*
M86HC05_INS(name,parameters,opcode)

parameters:
M68HC05_NONE none
M68HC05_IMM immediate
M68HC05_OFFSET8 8 bit address
M68HC05_OFFSET16 16 bit address
M68HC05_INDEX0 (X)
M68HC05_INDEX1 (X,8 bit offset)
M68HC05_INDEX2 (X,16 bit offset)
M68HC05_PCREL pc-relativ address
M68HC05_OFFSET8_PCREL 8 bit address+8 bit pc-relativ address

NOTE: The order may not be changed
*/

M68HC05_INS("adc",M68HC05_IMM,0xa9)
M68HC05_INS("adc",M68HC05_OFFSET8,0xb9)
M68HC05_INS("adc",M68HC05_OFFSET16,0xc9)
M68HC05_INS("adc",M68HC05_INDEX1,0xe9)
M68HC05_INS("adc",M68HC05_INDEX2,0xd9)
M68HC05_INS("adc",M68HC05_INDEX0,0xf9)

M68HC05_INS("add",M68HC05_IMM,0xab)
M68HC05_INS("add",M68HC05_OFFSET8,0xbb)
M68HC05_INS("add",M68HC05_OFFSET16,0xcb)
M68HC05_INS("add",M68HC05_INDEX1,0xeb)
M68HC05_INS("add",M68HC05_INDEX2,0xdb)
M68HC05_INS("add",M68HC05_INDEX0,0xfb)

M68HC05_INS("and",M68HC05_IMM,0xa4)
M68HC05_INS("and",M68HC05_OFFSET8,0xb4)
M68HC05_INS("and",M68HC05_OFFSET16,0xc4)
M68HC05_INS("and",M68HC05_INDEX1,0xe4)
M68HC05_INS("and",M68HC05_INDEX2,0xd4)
M68HC05_INS("and",M68HC05_INDEX0,0xf4)

M68HC05_INS("asl",M68HC05_OFFSET8,0x38)
M68HC05_INS("asla",M68HC05_NONE,0x48)
M68HC05_INS("aslx",M68HC05_NONE,0x58)
M68HC05_INS("asl",M68HC05_INDEX1,0x68)
M68HC05_INS("asl",M68HC05_INDEX0,0x78)

M68HC05_INS("asr",M68HC05_OFFSET8,0x37)
M68HC05_INS("asra",M68HC05_NONE,0x47)
M68HC05_INS("asrx",M68HC05_NONE,0x57)
M68HC05_INS("asr",M68HC05_INDEX1,0x67)
M68HC05_INS("asr",M68HC05_INDEX0,0x77)

M68HC05_INS("bcc",M68HC05_PCREL,0x24)

M68HC05_INS("bclr.0",M68HC05_OFFSET8,0x11)
M68HC05_INS("bclr.1",M68HC05_OFFSET8,0x13)
M68HC05_INS("bclr.2",M68HC05_OFFSET8,0x15)
M68HC05_INS("bclr.3",M68HC05_OFFSET8,0x17)
M68HC05_INS("bclr.4",M68HC05_OFFSET8,0x19)
M68HC05_INS("bclr.5",M68HC05_OFFSET8,0x1b)
M68HC05_INS("bclr.6",M68HC05_OFFSET8,0x1d)
M68HC05_INS("bclr.7",M68HC05_OFFSET8,0x1f)

M68HC05_INS("bcs",M68HC05_PCREL,0x25)
M68HC05_INS("beq",M68HC05_PCREL,0x27)
M68HC05_INS("bhcc",M68HC05_PCREL,0x28)
M68HC05_INS("bhcs",M68HC05_PCREL,0x29)
M68HC05_INS("bhi",M68HC05_PCREL,0x22)
M68HC05_INS("bhs",M68HC05_PCREL,0x24)
M68HC05_INS("bih",M68HC05_PCREL,0x2f)
M68HC05_INS("bil",M68HC05_PCREL,0x2e)

M68HC05_INS("bit",M68HC05_IMM,0xa5)
M68HC05_INS("bit",M68HC05_OFFSET8,0xb5)
M68HC05_INS("bit",M68HC05_OFFSET16,0xc5)
M68HC05_INS("bit",M68HC05_INDEX1,0xe5)
M68HC05_INS("bit",M68HC05_INDEX2,0xd5)
M68HC05_INS("bit",M68HC05_INDEX0,0xf5)

M68HC05_INS("blo",M68HC05_PCREL,0x25)
M68HC05_INS("bls",M68HC05_PCREL,0x23)
M68HC05_INS("bmc",M68HC05_PCREL,0x2c)
M68HC05_INS("bmi",M68HC05_PCREL,0x2b)
M68HC05_INS("bms",M68HC05_PCREL,0x2d)
M68HC05_INS("bne",M68HC05_PCREL,0x26)
M68HC05_INS("bpl",M68HC05_PCREL,0x2a)
M68HC05_INS("bra",M68HC05_PCREL,0x20)

M68HC05_INS("brclr.0",M68HC05_OFFSET8_PCREL,0x01)
M68HC05_INS("brclr.1",M68HC05_OFFSET8_PCREL,0x03)
M68HC05_INS("brclr.2",M68HC05_OFFSET8_PCREL,0x05)
M68HC05_INS("brclr.3",M68HC05_OFFSET8_PCREL,0x07)
M68HC05_INS("brclr.4",M68HC05_OFFSET8_PCREL,0x09)
M68HC05_INS("brclr.5",M68HC05_OFFSET8_PCREL,0x0b)
M68HC05_INS("brclr.6",M68HC05_OFFSET8_PCREL,0x0d)
M68HC05_INS("brclr.7",M68HC05_OFFSET8_PCREL,0x0f)

M68HC05_INS("brn",M68HC05_PCREL,0x21)

M68HC05_INS("brset.0",M68HC05_OFFSET8_PCREL,0x00)
M68HC05_INS("brset.1",M68HC05_OFFSET8_PCREL,0x02)
M68HC05_INS("brset.2",M68HC05_OFFSET8_PCREL,0x04)
M68HC05_INS("brset.3",M68HC05_OFFSET8_PCREL,0x06)
M68HC05_INS("brset.4",M68HC05_OFFSET8_PCREL,0x08)
M68HC05_INS("brset.5",M68HC05_OFFSET8_PCREL,0x0a)
M68HC05_INS("brset.6",M68HC05_OFFSET8_PCREL,0x0c)
M68HC05_INS("brset.7",M68HC05_OFFSET8_PCREL,0x0e)

M68HC05_INS("bset.0",M68HC05_OFFSET8,0x10)
M68HC05_INS("bset.1",M68HC05_OFFSET8,0x12)
M68HC05_INS("bset.2",M68HC05_OFFSET8,0x14)
M68HC05_INS("bset.3",M68HC05_OFFSET8,0x16)
M68HC05_INS("bset.4",M68HC05_OFFSET8,0x18)
M68HC05_INS("bset.5",M68HC05_OFFSET8,0x1a)
M68HC05_INS("bset.6",M68HC05_OFFSET8,0x1c)
M68HC05_INS("bset.7",M68HC05_OFFSET8,0x1e)

M68HC05_INS("bsr",M68HC05_PCREL,0xad)

M68HC05_INS("clc",M68HC05_NONE,0x98)
M68HC05_INS("cli",M68HC05_NONE,0x9a)

M68HC05_INS("clr",M68HC05_OFFSET8,0x3f)
M68HC05_INS("clra",M68HC05_NONE,0x4f)
M68HC05_INS("clrx",M68HC05_NONE,0x5f)
M68HC05_INS("clr",M68HC05_INDEX1,0x6f)
M68HC05_INS("clr",M68HC05_INDEX0,0x7f)

M68HC05_INS("cmp",M68HC05_IMM,0xa1)
M68HC05_INS("cmp",M68HC05_OFFSET8,0xb1)
M68HC05_INS("cmp",M68HC05_OFFSET16,0xc1)
M68HC05_INS("cmp",M68HC05_INDEX1,0xe1)
M68HC05_INS("cmp",M68HC05_INDEX2,0xd1)
M68HC05_INS("cmp",M68HC05_INDEX0,0xf1)

M68HC05_INS("com",M68HC05_OFFSET8,0x33)
M68HC05_INS("coma",M68HC05_NONE,0x43)
M68HC05_INS("comx",M68HC05_NONE,0x53)
M68HC05_INS("com",M68HC05_INDEX1,0x63)
M68HC05_INS("com",M68HC05_INDEX0,0x73)

M68HC05_INS("cpx",M68HC05_IMM,0xa3)
M68HC05_INS("cpx",M68HC05_OFFSET8,0xb3)
M68HC05_INS("cpx",M68HC05_OFFSET16,0xc3)
M68HC05_INS("cpx",M68HC05_INDEX1,0xe3)
M68HC05_INS("cpx",M68HC05_INDEX2,0xd3)
M68HC05_INS("cpx",M68HC05_INDEX0,0xf3)

M68HC05_INS("dec",M68HC05_OFFSET8,0x3a)
M68HC05_INS("deca",M68HC05_NONE,0x4a)
M68HC05_INS("decx",M68HC05_NONE,0x5a)
M68HC05_INS("dec",M68HC05_INDEX1,0x6a)
M68HC05_INS("dec",M68HC05_INDEX0,0x7a)

M68HC05_INS("eor",M68HC05_IMM,0xa8)
M68HC05_INS("eor",M68HC05_OFFSET8,0xb8)
M68HC05_INS("eor",M68HC05_OFFSET16,0xc8)
M68HC05_INS("eor",M68HC05_INDEX1,0xe8)
M68HC05_INS("eor",M68HC05_INDEX2,0xd8)
M68HC05_INS("eor",M68HC05_INDEX0,0xf8)

M68HC05_INS("inc",M68HC05_OFFSET8,0x3c)
M68HC05_INS("inca",M68HC05_NONE,0x4c)
M68HC05_INS("incx",M68HC05_NONE,0x5c)
M68HC05_INS("inc",M68HC05_INDEX1,0x6c)
M68HC05_INS("inc",M68HC05_INDEX0,0x7c)

M68HC05_INS("jmp",M68HC05_OFFSET8,0xbc)
M68HC05_INS("jmp",M68HC05_OFFSET16,0xcc)
M68HC05_INS("jmp",M68HC05_INDEX1,0xec)
M68HC05_INS("jmp",M68HC05_INDEX2,0xdc)
M68HC05_INS("jmp",M68HC05_INDEX0,0xfc)

M68HC05_INS("jsr",M68HC05_OFFSET8,0xbd)
M68HC05_INS("jsr",M68HC05_OFFSET16,0xcd)
M68HC05_INS("jsr",M68HC05_INDEX1,0xed)
M68HC05_INS("jsr",M68HC05_INDEX2,0xdd)
M68HC05_INS("jsr",M68HC05_INDEX0,0xfd)

M68HC05_INS("lda",M68HC05_IMM,0xa6)
M68HC05_INS("lda",M68HC05_OFFSET8,0xb6)
M68HC05_INS("lda",M68HC05_OFFSET16,0xc6)
M68HC05_INS("lda",M68HC05_INDEX1,0xe6)
M68HC05_INS("lda",M68HC05_INDEX2,0xd6)
M68HC05_INS("lda",M68HC05_INDEX0,0xf6)

M68HC05_INS("ldx",M68HC05_IMM,0xae)
M68HC05_INS("ldx",M68HC05_OFFSET8,0xbe)
M68HC05_INS("ldx",M68HC05_OFFSET16,0xce)
M68HC05_INS("ldx",M68HC05_INDEX1,0xee)
M68HC05_INS("ldx",M68HC05_INDEX2,0xde)
M68HC05_INS("ldx",M68HC05_INDEX0,0xfe)

M68HC05_INS("lsl",M68HC05_OFFSET8,0x38)
M68HC05_INS("lsla",M68HC05_NONE,0x48)
M68HC05_INS("lslx",M68HC05_NONE,0x58)
M68HC05_INS("lsl",M68HC05_INDEX1,0x68)
M68HC05_INS("lsl",M68HC05_INDEX0,0x78)

M68HC05_INS("lsr",M68HC05_OFFSET8,0x34)
M68HC05_INS("lsra",M68HC05_NONE,0x44)
M68HC05_INS("lsrx",M68HC05_NONE,0x54)
M68HC05_INS("lsr",M68HC05_INDEX1,0x64)
M68HC05_INS("lsr",M68HC05_INDEX0,0x74)

M68HC05_INS("mul",M68HC05_NONE,0x42)

M68HC05_INS("neg",M68HC05_OFFSET8,0x30)
M68HC05_INS("nega",M68HC05_NONE,0x40)
M68HC05_INS("negx",M68HC05_NONE,0x50)
M68HC05_INS("neg",M68HC05_INDEX1,0x60)
M68HC05_INS("neg",M68HC05_INDEX0,0x70)

M68HC05_INS("nop",M68HC05_NONE,0x9d)

M68HC05_INS("ora",M68HC05_IMM,0xaa)
M68HC05_INS("ora",M68HC05_OFFSET8,0xba)
M68HC05_INS("ora",M68HC05_OFFSET16,0xca)
M68HC05_INS("ora",M68HC05_INDEX1,0xea)
M68HC05_INS("ora",M68HC05_INDEX2,0xda)
M68HC05_INS("ora",M68HC05_INDEX0,0xfa)

M68HC05_INS("rol",M68HC05_OFFSET8,0x39)
M68HC05_INS("rola",M68HC05_NONE,0x49)
M68HC05_INS("rolx",M68HC05_NONE,0x59)
M68HC05_INS("rol",M68HC05_INDEX1,0x69)
M68HC05_INS("rol",M68HC05_INDEX0,0x79)

M68HC05_INS("ror",M68HC05_OFFSET8,0x36)
M68HC05_INS("rora",M68HC05_NONE,0x46)
M68HC05_INS("rorx",M68HC05_NONE,0x56)
M68HC05_INS("ror",M68HC05_INDEX1,0x66)
M68HC05_INS("ror",M68HC05_INDEX0,0x76)

M68HC05_INS("rsp",M68HC05_NONE,0x9c)

M68HC05_INS("rti",M68HC05_NONE,0x80)

M68HC05_INS("rts",M68HC05_NONE,0x81)

M68HC05_INS("sbc",M68HC05_IMM,0xa2)
M68HC05_INS("sbc",M68HC05_OFFSET8,0xb2)
M68HC05_INS("sbc",M68HC05_OFFSET16,0xc2)
M68HC05_INS("sbc",M68HC05_INDEX1,0xe2)
M68HC05_INS("sbc",M68HC05_INDEX2,0xd2)
M68HC05_INS("sbc",M68HC05_INDEX0,0xf2)

M68HC05_INS("sec",M68HC05_NONE,0x99)

M68HC05_INS("sei",M68HC05_NONE,0x9b)

M68HC05_INS("sta",M68HC05_OFFSET8,0xb7)
M68HC05_INS("sta",M68HC05_OFFSET16,0xc7)
M68HC05_INS("sta",M68HC05_INDEX1,0xe7)
M68HC05_INS("sta",M68HC05_INDEX2,0xd7)
M68HC05_INS("sta",M68HC05_INDEX0,0xf7)

M68HC05_INS("stop",M68HC05_NONE,0x8e)

M68HC05_INS("stx",M68HC05_OFFSET8,0xbf)
M68HC05_INS("stx",M68HC05_OFFSET16,0xcf)
M68HC05_INS("stx",M68HC05_INDEX1,0xef)
M68HC05_INS("stx",M68HC05_INDEX2,0xdf)
M68HC05_INS("stx",M68HC05_INDEX0,0xff)

M68HC05_INS("sub",M68HC05_IMM,0xa0)
M68HC05_INS("sub",M68HC05_OFFSET8,0xb0)
M68HC05_INS("sub",M68HC05_OFFSET16,0xc0)
M68HC05_INS("sub",M68HC05_INDEX1,0xe0)
M68HC05_INS("sub",M68HC05_INDEX2,0xd0)
M68HC05_INS("sub",M68HC05_INDEX0,0xf0)

M68HC05_INS("swi",M68HC05_NONE,0x83)

M68HC05_INS("tax",M68HC05_NONE,0x97)

M68HC05_INS("tst",M68HC05_OFFSET8,0x3d)
M68HC05_INS("tsta",M68HC05_NONE,0x4d)
M68HC05_INS("tstx",M68HC05_NONE,0x5d)
M68HC05_INS("tst",M68HC05_INDEX1,0x6d)
M68HC05_INS("tst",M68HC05_INDEX0,0x7d)

M68HC05_INS("txa",M68HC05_NONE,0x9f)

M68HC05_INS("wait",M68HC05_NONE,0x8f)
